@@ -17,8 +17,7 @@
 #include <math.h>
 #include <string.h>
 
-#include <gtk/gtkobject.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 #include <libart_lgpl/art_misc.h>
 #include <libart_lgpl/art_rect.h>
@@ -96,7 +95,7 @@ gnome_canvas_clipgroup_get_type (void)
 	static GType clipgroup_type;
 
 	if (!clipgroup_type) {
-		static const GTypeInfo object_info = {
+		const GTypeInfo object_info = {
 			sizeof (GnomeCanvasClipgroupClass),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
